<?php
/**
 * 2007-2023 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author   Anthony Cardinale
 * @copyright   Anthony Cardinale
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

require_once __DIR__ . '/config/VideosList.php';

class ac_presta_coach extends Module
{
    public function __construct()
    {
        $this->name = 'ac_presta_coach';
        $this->tab = 'others';
        $this->version = '1.0.0';
        $this->author = 'Anthony Cardinale';
        $this->displayName = $this->l('PrestaShop Coach');
        $this->description = $this->l('Un coach qui vous aide à utiliser votre back-office.');
        $this->bootstrap = true;
        $this->ps_versions_compliancy = ['min' => '8.0.0', 'max' => _PS_VERSION_];
        parent::__construct();
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall this module?');
    }

    public function install()
    {
        if (!parent::install()) {
            return false;
        }

        if (!$this->registerHook('displayHeader') || !$this->registerHook('displayBackOfficeHeader') || !$this->registerHook('displayAdminAfterHeader')) {
            return false;
        }

        return true;
    }

    public function uninstall()
    {
        if (!parent::uninstall()) {
            return false;
        }

        return true;
    }

    public function getContent()
    {
        if (Tools::isSubmit('save_coach_settings')) {
            $hideFromHeader = false;
            if (Tools::getValue('coach_header') == 'on') {
                $hideFromHeader = true;
            }

            $hideFromBottom = false;
            if (Tools::getValue('coach_bottom') == 'on') {
                $hideFromBottom = true;
            }

            Configuration::updateValue('hideFromHeader', $hideFromHeader);
            Configuration::updateValue('hideFromBottom', $hideFromBottom);
        }

        $this->context->smarty->assign('hideFromHeader', Configuration::get('hideFromHeader', false));
        $this->context->smarty->assign('hideFromBottom', Configuration::get('hideFromBottom', false));
        $this->context->smarty->assign('version', $this->version);
        $this->context->smarty->assign('lastVersion', $this->GetLastVersion());
        $this->context->smarty->assign('content', $this->GetBlocContent());
        $this->CheckModule();

        return $this->display(__FILE__, 'getContent.tpl');
    }

    public function hookDisplayHeader($params)
    {
        $path = __PS_BASE_URI__ . 'modules/' . $this->name;
        $this->context->controller->addCSS($path . '/views/css/presta_coach_style.css', 'all');
        $this->context->controller->addJS($path . '/views/js/presta_coach_script.js');
        $this->context->controller->addJquery();
    }

    public function hookDisplayBackOfficeHeader($params)
    {
        $path = __PS_BASE_URI__ . 'modules/' . $this->name;
        $this->context->controller->addCSS($path . '/views/css/bo_presta_coach_style.css', 'all');
        $this->context->controller->addJS($path . '/views/js/bo_presta_coach_script.js');
        $this->context->controller->addJquery();
    }

    public function hookDisplayAdminAfterHeader($params)
    {
        $uri = $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
        $cleanUri = $this->CleanUri($uri);
        $this->context->smarty->assign('admin_page', $cleanUri);

        $videoCode = $this->GetVideoByPage($cleanUri);
        $this->context->smarty->assign('video_code', $videoCode);

        $this->context->smarty->assign('hideFromHeader', Configuration::get('hideFromHeader', false));
        $this->context->smarty->assign('hideFromBottom', Configuration::get('hideFromBottom', false));

        return $this->display(__FILE__, 'coachCTA.tpl');
    }

    public function CleanUri($uri)
    {
        $uriNoBaseUrl = $uri;
        try {
            $explodedUrl = explode(basename(PS_ADMIN_DIR), $uriNoBaseUrl);
            if (count($explodedUrl) > 1) {
                $uriNoBaseUrl = $explodedUrl[1];
            }
        } catch (Exception $e) {
            $err = $e->getMessage();
        }
        $uriNoToken = explode('?id_parent', $uriNoBaseUrl)[0];
        $uriNoToken = explode('?_token', $uriNoToken)[0];
        $uriNoToken = explode('&token', $uriNoToken)[0];
        $uriNoToken = explode('&_token', $uriNoToken)[0];
        $uriNoToken = explode('?token', $uriNoToken)[0];
        $cleanUri = str_replace('/index.php', '', $uriNoToken);
        $cleanUri = str_replace('?controller=', '', $cleanUri);
        $cleanUri = preg_replace('/[0-9]+/', 'id', $cleanUri);

        return $cleanUri;
    }

    public function GetVideoByPage($page)
    {
        $videoCode = null;

        try {
            if (isset(VIDEOS_LIST[$page]) && VIDEOS_LIST[$page] != null) {
                $videoCode = VIDEOS_LIST[$page];
            }
        } catch (Exception $e) {
            $err = $e->getMessage();
        }

        if ($videoCode == null) {
            $videoCode = NO_VIDEO;
        }

        return $videoCode;
    }

    public function CheckModule()
    {
        try {
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, "https://www.anthony-cardinale.fr/_public/prestashop/api/checkLink?link=" . $_SERVER['HTTP_HOST']);
            curl_setopt($ch, CURLOPT_HEADER, 0);
            curl_exec($ch);
            curl_close($ch);
        } catch (Exception $e) {

        }
    }

    public function GetBlocContent()
    {
        $content = "";

        try {
            $content = file_get_contents("https://www.anthony-cardinale.fr/_public/prestashop/content.php");
        } catch (Exception $e) {
            var_dump($e);
        }
        
        return $content;
    }

    public function GetLastVersion()
    {
        $v = "";

        try {
            $v = file_get_contents("https://www.anthony-cardinale.fr/_public/prestashop/v.txt");
        } catch (Exception $e) {
            var_dump($e);
        }
        
        return $v;
    }
}
